#include <MoleGraph.h>
#include <eRCaGuy_analogReadXXbit.h>

//Oversampling for best results (perfect for small changes)
//instantiate an object of this library class; call it "adc"
eRCaGuy_analogReadXXbit adc;

MoleGraph moleGraph;

//Global constants
const uint8_t pin = A1; //analogRead pin
//constants required to determine the voltage at the pin; 
//BE SURE YOU USE THE CORRECT ONE OF THESE WHEN CALCULATING THE VOLTAGE FROM A READING! Take notes of how these constants are used below.
const float MAX_READING_10_bit = 1023.0;
const float MAX_READING_11_bit = 2046.0;
const float MAX_READING_12_bit = 4092.0;
const float MAX_READING_13_bit = 8184.0;
const float MAX_READING_14_bit = 16368.0;
const float MAX_READING_15_bit = 32736.0;
const float MAX_READING_16_bit = 65472.0;
const float MAX_READING_17_bit = 130944.0;
const float MAX_READING_18_bit = 261888.0;
const float MAX_READING_19_bit = 523776.0;
const float MAX_READING_20_bit = 1047552.0;
const float MAX_READING_21_bit = 2095104.0;

const float ZERO_PRESSURE = 25.86; // shift from zero pressure (calibration)

float analog_reading; //the ADC reading
float analog_10_reading; //the ADC reading
float V; //voltage calculated on the analog pin
float P; //pressure calculated on the analog pin    

void UpdateGraphChannels(void)
{
  moleGraph.SetChannelValue(1, analog_10_reading);
  moleGraph.SetChannelValue(2, analog_reading);
  moleGraph.SetChannelValue(3, V);
  moleGraph.SetChannelValue(4, P);
  //moleGraph.SetChannelValue(5, 0.0);
  //moleGraph.SetChannelValue(6, 0.0);
  //moleGraph.SetChannelValue(7, 0.0);
  //moleGraph.SetChannelValue(8, 0.0);
}
void MeasurementStartedCallback(void)
{
  digitalWrite(13, HIGH);
}
void MeasurementStoppedCallback(void)
{
  digitalWrite(13, LOW);
}
void MeasurementPausedCallback(void)
{
  digitalWrite(13, LOW);
}
void MeasurementContinuedCallback(void)
{
  digitalWrite(13, HIGH);
}


void setup()
{
  moleGraph.Setup();
  moleGraph.SetSendingCallback(&UpdateGraphChannels);
  moleGraph.SetMeasurementStartedCallback(&MeasurementStartedCallback);
  moleGraph.SetMeasurementStoppedCallback(&MeasurementStoppedCallback);
  moleGraph.SetMeasurementPausedCallback(&MeasurementPausedCallback);
  moleGraph.SetMeasurementContinuedCallback(&MeasurementContinuedCallback);
  
  //initialize pin 13 for measurement state initialization 
  pinMode(13, OUTPUT);
}

void loop()
{
  //Local variables
  unsigned long num_samples;
  uint8_t bits_of_precision; //bits of precision for the ADC (Analog to Digital Converter)
  
  moleGraph.CheckInput();

  num_samples = 25; 
  //12-bit ADC reading
  bits_of_precision = 12; //bits of precision for the ADC (Analog to Digital Converter)
  analog_10_reading = analogRead(pin);
  analog_reading = adc.analogReadXXbit(pin,bits_of_precision,num_samples); //get the avg. of [num_samples] 12-bit readings
  V = analog_reading/MAX_READING_12_bit*5.0; //voltage
  P = (analog_reading/MAX_READING_12_bit*700.0) - ZERO_PRESSURE; //pressure
  P = round(P*1000)/1000.0;  
}


